summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/tools/mousetoolaction.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kivio/kiviopart/tools/mousetoolaction.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kivio/kiviopart/tools/mousetoolaction.h')
-rw-r--r--kivio/kiviopart/tools/mousetoolaction.h55
1 files changed, 28 insertions, 27 deletions
diff --git a/kivio/kiviopart/tools/mousetoolaction.h b/kivio/kiviopart/tools/mousetoolaction.h
index fd172f68..0e528578 100644
--- a/kivio/kiviopart/tools/mousetoolaction.h
+++ b/kivio/kiviopart/tools/mousetoolaction.h
@@ -27,6 +27,7 @@ namespace Kivio {
class KIVIO_EXPORT MouseToolAction : public KRadioAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a mouse tool action with text and potential keyboard
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
*
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const KShortcut& cut = KShortcut(), QObject* parent = 0, const char* name = 0);
+ MouseToolAction(const TQString& text, const KShortcut& cut = KShortcut(), TQObject* tqparent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const KShortcut& cut,
- const QObject* receiver, const char* slot, QObject* parent, const char* name = 0);
+ MouseToolAction(const TQString& text, const KShortcut& cut,
+ const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const QIconSet& pix, const KShortcut& cut = KShortcut(),
- QObject* parent = 0, const char* name = 0);
+ MouseToolAction(const TQString& text, const TQIconSet& pix, const KShortcut& cut = KShortcut(),
+ TQObject* tqparent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const QString& pix, const KShortcut& cut = KShortcut(),
- QObject* parent = 0, const char* name = 0);
+ MouseToolAction(const TQString& text, const TQString& pix, const KShortcut& cut = KShortcut(),
+ TQObject* tqparent = 0, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const QIconSet& pix, const KShortcut& cut,
- const QObject* receiver, const char* slot, QObject* parent, const char* name = 0);
+ MouseToolAction(const TQString& text, const TQIconSet& pix, const KShortcut& cut,
+ const TQObject* receiver, const char* slot, TQObject* tqparent, const char* name = 0);
/**
* @param text The text that will be displayed.
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke to execute this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(const QString& text, const QString& pix, const KShortcut& cut,
- const QObject* receiver, const char* slot,
- QObject* parent, const char* name = 0);
+ MouseToolAction(const TQString& text, const TQString& pix, const KShortcut& cut,
+ const TQObject* receiver, const char* slot,
+ TQObject* tqparent, const char* name = 0);
/**
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- MouseToolAction(QObject* parent = 0, const char* name = 0);
+ MouseToolAction(TQObject* tqparent = 0, const char* name = 0);
~MouseToolAction();
@@ -115,7 +116,7 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param widget The GUI element to display this action.
* @param index The index of the item.
*/
- virtual int plug(QWidget* widget, int index = -1);
+ virtual int plug(TQWidget* widget, int index = -1);
signals:
void doubleClicked();
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param text The text that will be displayed.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke to execute this action.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The icons that go with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke to execute this action.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
* @param pix The dynamically loaded icon that goes with this action.
* @param cut The corresponding keyboard accelerator (shortcut).
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke to execute this action.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke to execute this action.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -35,72 +36,72 @@ class KIVIO_EXPORT MouseToolAction : public KRadioAction
/**
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/